"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LabelService = void 0;
const graphql_request_1 = require("graphql-request");
const constellation_sxa_nextjs_1 = require("@constellation4sitecore/constellation-sxa-nextjs");
const foundation_mapper_1 = require("@constellation4sitecore/foundation-mapper");
class LabelService {
    /**
     * Initialize the label service
     * @param layoutData : Layout service data
     */
    constructor(layoutData) {
        var _a;
        this.language = (layoutData === null || layoutData === void 0 ? void 0 : layoutData.sitecore.context.language)
            ? layoutData === null || layoutData === void 0 ? void 0 : layoutData.sitecore.context.language
            : constellation_sxa_nextjs_1.config.defaultLanguage;
        this.contextItem = ((_a = layoutData === null || layoutData === void 0 ? void 0 : layoutData.sitecore.route) === null || _a === void 0 ? void 0 : _a.itemId) ? layoutData.sitecore.route.itemId : null;
    }
    /**
     * Get labels for a given template ID
     * @param templateId : Template ID of the labels
     * @returns Labels
     */
    getLabelsForView(templateId) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            const graphqlFactory = (0, constellation_sxa_nextjs_1.createGraphQLClientFactory)();
            const graphQLClient = graphqlFactory({
                debugger: constellation_sxa_nextjs_1.debug.labels,
            });
            const query = (0, graphql_request_1.gql) `
      query getLabelsForView($contextItem: String, $labelsTemplate: String!, $language: String!) {
        labels: search(
          where: {
            AND: [
              { name: "_templates", value: $labelsTemplate }
              { name: "_name", value: "__Standard Values", operator: NEQ }
            ]
          }
        ) {
          results {
            name
            path
            fields(ownFields: true) {
              name
              jsonValue
            }
          }
        }
        siteRoot: item(path: $contextItem, language: $language) {
          ancestors(hasLayout: true) {
            name
            parent {
              path
            }
          }
        }
      }
    `;
            try {
                const result = yield graphQLClient.request(query, {
                    contextItem: this.contextItem,
                    labelsTemplate: templateId,
                    language: this.language,
                });
                if (result.labels.results.length == 0) {
                    constellation_sxa_nextjs_1.debug.labels(`No labels found for templateId: ${templateId}. Did you forget to publish?`);
                    return null;
                }
                const home = (_a = result.siteRoot) === null || _a === void 0 ? void 0 : _a.ancestors.find((ancestor) => ancestor.name.toLowerCase() === 'home');
                const labelItem = home
                    ? result.labels.results.filter((label) => label.path.startsWith(home.parent.path))[0]
                    : result.labels.results[0];
                const label = (0, foundation_mapper_1.mapToNew)(labelItem);
                return label;
            }
            catch (error) {
                constellation_sxa_nextjs_1.debug.labels(`Error fetching labels for templateId: ${templateId}. Verify that template exists. Error: ${error}`);
                return null;
            }
        });
    }
}
exports.LabelService = LabelService;
